@@ -420,9 +420,11 @@ class FileHelper:
         aggregated_segment: Optional[np.ndarray] = None
 
         prefix = f"({at_hour:02}h:{at_minute:02}m)"
-        for intersection in intersections:
+        for i, intersection in enumerate(intersections):
             if intersection.duration_secs == 0:
-                self.log.warning("No data from intersection")
+                self.log.warning(
+                    f"{prefix}: No data from intersection {i} for {intersection.entry.uri}"
+                )
                 continue
 
             ss = self._get_sound_status(intersection.entry.uri)
